package data.scripts.world;

import java.awt.Color;
import com.fs.starfarer.api.campaign.SectorGeneratorPlugin;
import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.FactionAPI;
import com.fs.starfarer.api.campaign.JumpPointAPI;
import com.fs.starfarer.api.campaign.LocationAPI;
import com.fs.starfarer.api.campaign.OrbitAPI;
import com.fs.starfarer.api.campaign.PlanetAPI;
import com.fs.starfarer.api.campaign.SectorAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.campaign.StarSystemAPI;
import com.fs.starfarer.api.fleet.FleetMemberType;
import com.fs.starfarer.api.impl.campaign.CoreCampaignPluginImpl;

@SuppressWarnings("unchecked")
public class instrumentalityGen implements SectorGeneratorPlugin {

   public void generate(SectorAPI sector) {
   
    		StarSystemAPI system = sector.createStarSystem("Issa");
                system.getLocation().set(1200, -9000);
		system.setBackgroundTextureFilename("graphics/backgrounds/background2.jpg");
                
                


		// create the star and generate the hyperspace anchor for this system
		PlanetAPI star = system.initStar("star_yellow", // id in planets.json
										 830f, 		// radius (in pixels at default zoom)
										 1200, -9000);   // location in hyperspace
		
		system.setLightColor(new Color(255, 255, 255)); // light color in entire system, affects all entities
		


		/*
		 * addPlanet() parameters:
		 * 1. What the planet orbits (orbit is always circular)
		 * 2. Name
		 * 3. Planet type id in planets.json
		 * 4. Starting angle in orbit, i.e. 0 = to the right of the star
		 * 5. Planet radius, pixels at default zoom
		 * 6. Orbit radius, pixels at default zoom
		 * 7. Days it takes to complete an orbit. 1 day = 10 seconds.
		 */		
		
		PlanetAPI a1 = system.addPlanet(star, "Enyu", "gas_giant", 65, 305, 1800, 40);
		PlanetAPI a2 = system.addPlanet(star, "Issa-Prime", "toxic", 90, 140, 4600, 320);
		
		PlanetAPI a21 = system.addPlanet(a2, "Korbos", "barren", 45, 60, 600, 22);
		
		PlanetAPI a3 = system.addPlanet (a2, "Ral-Leon", "desert", 130, 130, 5000, 400);		

		PlanetAPI a4 = system.addPlanet(star, "Narim", "ice_giant", 280, 250, 8500, 520);
		
		
		
		a1.setCustomDescriptionId("planet_enyu");
		a2.setCustomDescriptionId("planet_issa_prime");
		a21.setCustomDescriptionId("planet_korbos");
		a3.setCustomDescriptionId("planet_ral_leon");
		a4.setCustomDescriptionId("planet_narim");
		
		
		
		a2.getSpec().setAtmosphereColor(new Color(160,110,45,140));
		a2.getSpec().setCloudColor(new Color(255,164,96,200));
		a2.getSpec().setTilt(15);
		a2.applySpecChanges();
		
		/*
		 * addAsteroidBelt() parameters:
		 * 1. What the belt orbits
		 * 2. Number of asteroids
		 * 3. Orbit radius
		 * 4. Belt width
		 * 6/7. Range of days to complete one orbit. Value picked randomly for each asteroid. 
		 */
		system.addAsteroidBelt(star, 480, 5500, 190, 90, 180);
		
		
		/*
		 * addRingBand() parameters:
		 * 1. What it orbits
		 * 2. Category under "graphics" in settings.json
		 * 3. Key in category
		 * 4. Width of band within the texture
		 * 5. Index of band
		 * 6. Color to apply to band
		 * 7. Width of band (in the game)
		 * 8. Orbit radius (of the middle of the band)
		 * 9. Orbital period, in days
		 */
				

	
		SectorEntityToken instrumentalityStation = system.addOrbitalStation(system.getEntityByName("Issa-Prime"), 45, 300, 50, "Civil Directory", "instrumentality");

                system.addSpawnPoint(new instrumentalitySpawnPoint(sector, system, 14f, 1, instrumentalityStation));


		JumpPointAPI jumpPoint = Global.getFactory().createJumpPoint("Jump Point Alpha");
		OrbitAPI orbit = Global.getFactory().createCircularOrbit(a2, 0, 500, 30);
		jumpPoint.setOrbit(orbit);
		jumpPoint.setRelatedPlanet(a2);
		jumpPoint.setStandardWormholeToHyperspaceVisual();
		system.addEntity(jumpPoint);
		
		system.autogenerateHyperspaceJumpPoints(true, true);
			
	
		}
	
}

