package data.scripts.world.systems;

import java.util.List;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.campaign.CampaignFleetAPI;
import com.fs.starfarer.api.campaign.CargoAPI;
import com.fs.starfarer.api.campaign.FleetAssignment;
import com.fs.starfarer.api.campaign.LocationAPI;
import com.fs.starfarer.api.campaign.SectorAPI;
import com.fs.starfarer.api.campaign.SectorEntityToken;
import com.fs.starfarer.api.campaign.StarSystemAPI;
import com.fs.starfarer.api.fleet.FleetMemberAPI;
import com.fs.starfarer.api.fleet.FleetMemberType;

import data.scripts.world.BaseSpawnPoint;

@SuppressWarnings("unchecked")
public class IndependentTraderSpawnPoint extends BaseSpawnPoint {

	 private final SectorEntityToken convoyDestination;

	public IndependentTraderSpawnPoint(SectorAPI sector, LocationAPI location, 
							float daysInterval, int maxFleets, SectorEntityToken anchor,
							SectorEntityToken convoyDestination) {
		super(sector, location, daysInterval, maxFleets, anchor);
		this.convoyDestination = convoyDestination;
	}

	private int convoyNumber = 0;
	
	@Override
	protected CampaignFleetAPI spawnFleet() {
		String type = null;
		float r = (float) Math.random();
		if (r > .75f) {
			type = "loneTrader";
		} else if (r > 0.5f) {
			type = "trader1";
		} else if (r > 0.25f) {
			type = "trader2";
		} else {
			type = "trader3";
		}
		
		StarSystemAPI corvus = Global.getSector().getStarSystem("Corvus");
		float angle = (float) ((float) Math.random() * Math.PI * 2f);
		float x = (float) (Math.cos(angle) * 12000f) + corvus.getLocation().x;
		float y = (float) (Math.sin(angle) * 12000f) + corvus.getLocation().y;
		SectorEntityToken spawnPoint = Global.getSector().getHyperspace().createToken(x, y);
		
		CampaignFleetAPI fleet = getSector().createFleet("independent", type);
		spawnPoint.getContainingLocation().spawnFleet(spawnPoint, 0, 0, fleet);

		fleet.setPreferredResupplyLocation(convoyDestination);
		
		CargoAPI cargo = fleet.getCargo();

		addRandomWeapons(cargo, (int) (Math.random() * 3f) + 2);
		addRandomShips(fleet, (int) (Math.random() * 2f) + 0);
		
		fleet.addAssignment(FleetAssignment.DELIVER_RESOURCES, convoyDestination, 1000);
		fleet.addAssignment(FleetAssignment.GO_TO_LOCATION_AND_DESPAWN, spawnPoint, 1000);
		
		convoyNumber++;
		return fleet;
	}
	
	private void addRandomWeapons(CargoAPI cargo, int count) {
		List weaponIds = getSector().getAllWeaponIds();
		for (int i = 0; i < count; i++) {
			String weaponId = (String) weaponIds.get((int) (weaponIds.size() * Math.random()));
			int quantity = (int)(Math.random() * 4f + 2f);
			cargo.addWeapons(weaponId, quantity);
		}
	}
	
	private void addRandomShips(CampaignFleetAPI fleet, int count) {
		List wings = getSector().getAllFighterWingIds();
		List ships = getSector().getAllEmptyVariantIds();
		for (int i = 0; i < count; i++) {
			if ((float) Math.random() > 0.7f) {
				String wing = (String) wings.get((int) (wings.size() * Math.random()));
				FleetMemberAPI member = Global.getFactory().createFleetMember(FleetMemberType.FIGHTER_WING, wing);
				fleet.getFleetData().addFleetMember(member);
				member.getRepairTracker().setMothballed(true);
			} else {
				String ship = (String) ships.get((int) (ships.size() * Math.random()));
				FleetMemberAPI member = Global.getFactory().createFleetMember(FleetMemberType.SHIP, ship);
				fleet.getFleetData().addFleetMember(member);
				member.getRepairTracker().setMothballed(true);
			}
		}
	}
									
}



